@@ -2,6 +2,6 @@ name = "pycromanager"
 
 from pycromanager.acquisitions import Acquisition, MagellanAcquisition, XYTiledAcquisition
 from pycromanager.acq_util import start_headless, multi_d_acquisition_events
-from pycromanager.data import Dataset
+from ndtiff import Dataset
 from pycromanager.java_classes import *
 from ._version import __version__, version_info
